============
Contributing
============

If you're thinking about contributing, it's really quite simple. There is no need to feel daunted. You can contribute in a variety of ways:

Report bugs
Bug fixes
New behaviour
Improve the documentation
Write tests
Improve performance
Add additional support i.e. new versions of Python or PyPy
You can view a list of tasks that need work on the `todo <https://kura.gg/blackhole/todo.html>`__ page.

The `api <https://kura.gg/blackhole/api.html>`__ section also has a wealth of information on how the server works and how you can modify it or use parts of it.
